Skip to main content
https://img.shields.io/travis/coagulant/critics.svg https://img.shields.io/coveralls/coagulant/critics.svg https://img.shields.io/pypi/v/critics.svg https://img.shields.io/badge/licence-BSD-blue.svg https://img.shields.io/badge/status-beta-yellow.svg
Usage: critics [OPTIONS]

  Notify about new reviews in AppStore and Google Play in slack.

  Launch command using supervisor or using screen/tmux/etc. Reviews are
  fetched for multiple apps and languages in --beat=300 interval.

Options:
  --ios TEXT                   ios app id, e.g. 122434343
  --ios-channel TEXT           Slack channel for ios notifications, optional
  --android TEXT               Android app name, e.g. "com.rovio.angrybirds"
  --android-channel TEXT       Slack channel for android notifications, optional
  --language TEXT              ISO 639-1 languages of review [default: system locale]
  --slack-webhook TEXT         Slack webhook absolute URL, required
  --parse-max-entries INTEGER  Number of feed entries to look into [default: 10]
  --beat INTEGER               Number of seconds between polling feed [default: 300]
  --verbose / --short
  --notify / --no-notify
  --persist / --no-persist
  --model PATH
  --daemonize / --run-once
  --version
  --help                       Show this message and exit.

Examples

Track English and Russian reviews for iOS and Android Angry Birds apps and post them to separate channels:

critics --ios=343200656 --android=com.rovio.angrybirds \
        --slack-webhook=YOUR_SLACK_WEBHOOK_URL \
        --language=en --language=ru \
        --ios-channel="#ios_reviews" --android-channel="#android_reviews"

Previous command, but using env variables:

CRITICS_IOS=343200656 CRITICS_ANDROID=com.rovio.angrybirds \
CRITICS_SLACK_WEBHOOK=YOUR_SLACK_WEBHOOK_URL CRITICS_LANGUAGE="en ru" \
CRITICS_IOS_CHANNEL="#ios_reviews" CRITICS_ANDROID_CHANNEL="#android_reviews" \
critics

For demo purpose (does not require slack): parse ios feed for MyBook app and print reviews in stdout:

critics --ios=556540446 --run-once --no-notify --no-persist --verbose

How it looks

Heroes HD Android reviews

Changelog

0.2.1 (2015-03-20)

  • Change default request timeout to 5 seconds

0.2.0 (2015-03-19)

  • Multiple languages support

  • English and Russian translations

  • Usable url for iOS review

0.1.0 (2015-03-09)

  • Initial release

Metadata

Release files for critics 0.2.1

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for critics 0.2.1
File Size Uploaded
critics-0.2.1.tar.gz 44.3 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for critics 0.2.1
File Interpreter ABI Platform
critics-0.2.1-py2.py3-none-any.whl Python 2, Python 3 none any Details

Total release size: 55.8 kB

Release files / critics-0.2.1.tar.gz

Download URL critics-0.2.1.tar.gz
Size 44.3 kB
Tags Source
SHA-256 checksum
How to use checksums
0026b1352c902d0226803cbf710a8b33d2cd31a15e3a5c89478a5688800d9ec7
BLAKE2b-256 checksum
How to use checksums
b83411a5f79191c3a0efbe3a2202aef7b425c759c7f179e9fa5340a5cf40f9ff
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release files / critics-0.2.1-py2.py3-none-any.whl

Download URL critics-0.2.1-py2.py3-none-any.whl
Size 11.5 kB
Tags Python 2 Python 3
SHA-256 checksum
How to use checksums
5fba885921aba03c81fd36925fbd43265ca38869e86ba462d116b73b834c0417
BLAKE2b-256 checksum
How to use checksums
458f159dddf1b6d4d79186f1f2978490c544b2cde5847a2ec1e1b0aa73b2734c
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No

Release history Release notifications | RSS feed

This release

0.2.1 This release

2 release files

0.2.0

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page